# Load in the 'phyloseq', 'tidyverse', and 'ape' package
library(phyloseq)
library(ape) 
library(tidyverse)
library(vegan)
library(picante)
library(ggplot2)

#### Load in RData ####
load("parkinsons_dataset_rare.RData")
load("parkinsons_dataset_final.RData")

parkinsons_dataset_rare_no.NA <- parkinsons_dataset_rare %>% 
  subset_samples(!is.na(Sodium))%>% 
  subset_samples(!is.na(Age))%>% 
  subset_samples(!is.na(Disease)) %>%
  subset_samples(Sodium < 5000)

#_____________________________________________________
# Alpha Diversity
plot_richness(parkinsons_dataset_rare_no.NA) 

#_____________________________________________________
# Richness
plot_alpha_richness_salt <- plot_richness(parkinsons_dataset_rare_no.NA, x = "Sodium", measures = c("Observed")) +
  xlab("Sodium") +  
  geom_point()+
  geom_smooth(method="lm") + 
  theme(text = element_text(size=20))
plot_alpha_richness_salt

ggsave(filename = "plot_alpha_richness_salt.png"
       , plot_alpha_richness_salt
       , height=5, width=5)

stat_alpha_richness_salt <- summary(glm(value ~ Sodium + Disease + Age,
                                        data= plot_alpha_richness_salt$data %>% filter(variable == "Observed")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Observe")
stat_alpha_richness_salt

write.csv(stat_alpha_richness_salt, file = "stat_alpha_richness_salt.csv", row.names = FALSE)

#_____________________________________________________
# Shannon
plot_alpha_shannon_salt <- plot_richness(parkinsons_dataset_rare_no.NA, x = "Sodium", measures = c("Shannon")) +
  xlab("Sodium") + 
  geom_point()+
  geom_smooth(method="lm") + 
  theme(text = element_text(size=20))
plot_alpha_shannon_salt

ggsave(filename = "plot_alpha_shannon_salt.png"
       , plot_alpha_shannon_salt
       , height=5, width=5)

stat_alpha_shannon_salt <- summary(glm(value ~ Sodium + Disease + Age,
                                        data= plot_alpha_shannon_salt$data %>% filter(variable == "Shannon")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Shannon")
stat_alpha_shannon_salt

write.csv(stat_alpha_shannon_salt, file = "stat_alpha_shannon_salt.csv", row.names = FALSE)

#_____________________________________________________
# Faith ~ phylogenetic diversity

# calculate Faith's phylogenetic diversity as PD
alpha_faith_salt <- pd(t(otu_table(parkinsons_dataset_rare_no.NA)), phy_tree(parkinsons_dataset_rare_no.NA),
                       include.root=F) 

# add PD to metadata table
sample_data(parkinsons_dataset_rare_no.NA)$PD <- alpha_faith_salt$PD

# plot any metadata category against the PD
plot_alpha_faith_salt <- ggplot(sample_data(parkinsons_dataset_rare_no.NA), aes(Sodium, PD)) + 
  geom_point() +
  xlab("Sodium") +
  ylab("Phylogenetic Diversity") + 
  geom_smooth(method="lm") + 
  theme(text = element_text(size=20)) + 
  theme(axis.text.x = element_text(angle = -90))
plot_alpha_faith_salt

ggsave(filename = "plot_alpha_faith_salt.png"
       , plot_alpha_faith_salt
       , height=5, width=5)

stat_alpha_faith_salt_table <- parkinsons_dataset_rare_no.NA %>% psmelt() %>% select(Sodium, PD, Disease, Age) %>% unique()
stat_alpha_faith_salt <- summary(glm(PD ~ Sodium + Disease + Age,
                                       data= stat_alpha_faith_salt_table))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("Phylogenetic Diversity") %>%
  mutate(alpha = "Faith")
stat_alpha_faith_salt

write.csv(stat_alpha_faith_salt, file = "stat_alpha_faith_salt.csv", row.names = FALSE)

#_____________________________________________________
# Beta Diversity 

# Separate Sodium into tertiles
sample_data(parkinsons_dataset_rare_no.NA)$sodium_tertiles <- ntile(sample_data(parkinsons_dataset_rare_no.NA)$Sodium, 3)

# Prepare dataframe for PERMANOVA
meta_wdiv <- data.frame(sample_data(parkinsons_dataset_rare_no.NA), estimate_richness(parkinsons_dataset_rare_no.NA))

#_____________________________________________________
# Bray-Curtis

# Plot PCoA plot with Bray-Curtis Metrics
beta_distance_bc <- distance(parkinsons_dataset_rare_no.NA, method="bray")
beta_pcoa_bc <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance=beta_distance_bc)

plot_beta_pcoa_bc <- plot_ordination(parkinsons_dataset_rare_no.NA, beta_pcoa_bc, color="sodium_tertiles", shape ="Disease")+ 
  scale_color_gradient(low = "yellow", high = "purple")  + 
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  geom_point(size=1)+
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) +
  theme_gray(base_size=18)
plot_beta_pcoa_bc

ggsave("plot_beta_pcoa_bc.png"
       , plot_beta_pcoa_bc
       , height=8, width=8)

# bray PERMANOVA
beta_bray <- vegdist(t(otu_table(parkinsons_dataset_rare_no.NA)), method="bray")
bray <- adonis2(beta_bray ~ `Sodium`+Disease+Age, data=meta_wdiv)
bray

write.csv(bray, file = "bray.csv", row.names = TRUE)

#_____________________________________________________
# Weighted Unifrac

dm_unifrac_weight <- UniFrac(parkinsons_dataset_rare_no.NA, weighted=TRUE)

# Plot the above as an ordination to a PCoA plot, with Stats Elipses
beta_ord.unifrac <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance="unifrac")
plot_beta_ord.unifrac_sodium <-plot_ordination(parkinsons_dataset_rare_no.NA, beta_ord.unifrac, color = "sodium_tertiles") +
  scale_color_gradient(low = "yellow", high = "purple") + 
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  geom_point(size=1)+
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) +
  theme_gray(base_size=18)
plot_beta_ord.unifrac_sodium

ggsave("plot_beta_ord.unifrac_sodium.png"
       , plot_beta_ord.unifrac_sodium
       , height=8, width=8)

# Weighted Unifrac PERMANOVA
unif_weight <- adonis2(dm_unifrac_weight ~ `Sodium`+Disease+Age, data=meta_wdiv)
unif_weight
write.csv(unif_weight, file = "unif_weight.csv", row.names = TRUE)

#_____________________________________________________
# Unweighted Unifrac

dm_unifrac_unweight <- UniFrac(parkinsons_dataset_rare_no.NA, weighted=FALSE)

# Plot the above as an ordination to a PCoA plot, with Stats Elipses
beta_ord.wunifrac <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance="wunifrac")
plot_beta_ord.wunifrac_sodium <-plot_ordination(parkinsons_dataset_rare_no.NA, beta_ord.wunifrac, color = "sodium_tertiles") +
  scale_color_gradient(low = "yellow", high = "purple") + 
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  geom_point(size=1)+
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) + 
  theme_gray(base_size=18)
plot_beta_ord.wunifrac_sodium

ggsave("plot_beta_ord.wunifrac_sodium.png"
       , plot_beta_ord.wunifrac_sodium
       , height=8, width=8)

# Unweighted Unifrac PERMANOVA
unif_unweight <- adonis2(dm_unifrac_unweight ~ `Sodium`+Disease+Age, data=meta_wdiv)
unif_unweight
write.csv(unif_unweight, file = "unif_unweight.csv", row.names = TRUE)

#_____________________________________________________