# Load in the 'phyloseq', 'tidyverse', and 'ape' package
library(phyloseq)
library(ape) 
library(tidyverse)
library(vegan)
library(picante)
library(ggplot2)

#### Load in RData ####
load("parkinsons_dataset_rare.RData")
load("parkinsons_dataset_final.RData")

parkinsons_dataset_rare_no.NA <- parkinsons_dataset_rare %>% 
  subset_samples(!is.na(Sodium))%>% 
  subset_samples(!is.na(Age))%>% 
  subset_samples(!is.na(Disease)) %>%
  subset_samples(Sodium < 5000)

#_____________________________________________________
# Aim 3
estimate_richness(parkinsons_dataset_rare_no.NA)
#_____________________________________________________
# Richness
plot_alpha_richness_disease <- plot_richness(parkinsons_dataset_rare_no.NA, x = "Sodium", measures = c("Observed")) +
  xlab("Sodium") +  
  geom_point()+
  geom_smooth(method="lm") + 
  facet_wrap(.~Disease) + 
  theme(text = element_text(size=20))
plot_alpha_richness_disease

ggsave(filename = "plot_alpha_richness_disease.png"
       , plot_alpha_richness_disease
       , height=5, width=10)

# Disease
stat_alpha_richness_disease <- summary(glm(value ~ Disease + Age,
                                        data= plot_alpha_richness_disease$data %>% filter(variable == "Observed")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Observe")
stat_alpha_richness_disease
write.csv(stat_alpha_richness_disease, file = "stat_alpha_richness_disease.csv", row.names = FALSE)

# Control Sodium
stat_alpha_richness_disease_con <- summary(glm(value ~ Sodium + Age,
                                           data= plot_alpha_richness_disease$data %>% filter(variable == "Observed", Disease == "Control")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Observe")
stat_alpha_richness_disease_con
write.csv(stat_alpha_richness_disease_con, file = "stat_alpha_richness_disease_con.csv", row.names = FALSE)

# PD Sodium
stat_alpha_richness_disease_pd <- summary(glm(value ~ Sodium + Age,
                                               data= plot_alpha_richness_disease$data %>% filter(variable == "Observed", Disease == "PD")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Observe")
stat_alpha_richness_disease_pd
write.csv(stat_alpha_richness_disease_pd, file = "stat_alpha_richness_disease_pd.csv", row.names = FALSE)

#_____________________________________________________
# Shannon
plot_alpha_shannon_disease <- plot_richness(parkinsons_dataset_rare_no.NA, x = "Sodium", measures = c("Shannon")) +
  xlab("Sodium") + 
  geom_point()+
  geom_smooth(method="lm") + 
  facet_wrap(.~Disease) + 
  theme(text = element_text(size=20))
plot_alpha_shannon_disease

ggsave(filename = "plot_alpha_shannon_disease.png"
       , plot_alpha_shannon_disease
       , height=5, width=10)

# Disease
stat_alpha_shannon_disease <- summary(glm(value ~ Disease + Age,
                                       data= plot_alpha_shannon_disease$data %>% filter(variable == "Shannon")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Shannon")
stat_alpha_shannon_disease
write.csv(stat_alpha_shannon_disease, file = "stat_alpha_shannon_disease.csv", row.names = FALSE)

# Control Sodium
stat_alpha_shannon_disease_con <- summary(glm(value ~ Sodium + Age,
                                          data= plot_alpha_shannon_disease$data %>% filter(variable == "Shannon", Disease == "Control")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Shannon")
stat_alpha_shannon_disease_con
write.csv(stat_alpha_shannon_disease_con, file = "stat_alpha_shannon_disease_con.csv", row.names = FALSE)

# PD sodium
stat_alpha_shannon_disease_pd <- summary(glm(value ~ Sodium + Age,
                                              data= plot_alpha_shannon_disease$data %>% filter(variable == "Shannon", Disease == "PD")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("variables") %>%
  mutate(alpha = "Shannon")
stat_alpha_shannon_disease_pd
write.csv(stat_alpha_shannon_disease_pd, file = "stat_alpha_shannon_disease_pd.csv", row.names = FALSE)

#_____________________________________________________
# Faith ~ phylogenetic diversity

# calculate Faith's phylogenetic diversity as PD
alpha_faith_disease <- pd(t(otu_table(parkinsons_dataset_rare_no.NA)), phy_tree(parkinsons_dataset_rare_no.NA),
                       include.root=F) 

# add PD to metadata table
sample_data(parkinsons_dataset_rare_no.NA)$PD <- alpha_faith_disease$PD

# plot any metadata category against the PD
plot_alpha_faith_disease <- ggplot(sample_data(parkinsons_dataset_rare_no.NA), aes(Sodium, PD)) + 
  geom_point() +
  xlab("Sodium") +
  ylab("Phylogenetic Diversity") + 
  geom_smooth(method="lm") +
  facet_wrap(.~Disease) + 
  theme(text = element_text(size=20))+ 
  theme(axis.text.x = element_text(angle = -90))
plot_alpha_faith_disease

ggsave(filename = "plot_alpha_faith_disease.png"
       , plot_alpha_faith_disease
       , height=5, width=10)

stat_alpha_faith_disease_table <- parkinsons_dataset_rare_no.NA %>% psmelt() %>% select(Sodium, PD, Disease, Age) %>% unique()

# Disease
stat_alpha_faith_disease <- summary(glm(PD ~ Disease + Age,
                                     data= stat_alpha_faith_disease_table))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("Phylogenetic Diversity") %>%
  mutate(alpha = "Faith")
stat_alpha_faith_disease
write.csv(stat_alpha_faith_disease, file = "stat_alpha_faith_disease.csv", row.names = FALSE)

# Control Sodium
stat_alpha_faith_disease_con <- summary(glm(PD ~ Sodium + Age,
                                        data= stat_alpha_faith_disease_table %>% filter(Disease == "Control")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("Phylogenetic Diversity") %>%
  mutate(alpha = "Faith")
stat_alpha_faith_disease_con
write.csv(stat_alpha_faith_disease_con, file = "stat_alpha_faith_disease_con.csv", row.names = FALSE)

# PD Sodium
stat_alpha_faith_disease_pd <- summary(glm(PD ~ Sodium + Age,
                                            data= stat_alpha_faith_disease_table %>% filter(Disease == "PD")))$coefficients %>%
  as.data.frame() %>%
  rownames_to_column("Phylogenetic Diversity") %>%
  mutate(alpha = "Faith")
stat_alpha_faith_disease_pd
write.csv(stat_alpha_faith_disease_pd, file = "stat_alpha_faith_disease_pd.csv", row.names = FALSE)

################################################################################################################

#_____________________________________________________
# Beta Diversity 

# Separate Sodium into tertiles
sample_data(parkinsons_dataset_rare_no.NA)$sodium_tertiles <- ntile(sample_data(parkinsons_dataset_rare_no.NA)$Sodium, 3)

# Make Data frame for PERMANOVA
meta_wdiv <- data.frame(sample_data(parkinsons_dataset_rare_no.NA), estimate_richness(parkinsons_dataset_rare_no.NA))
meta_wdiv_con <- meta_wdiv %>%
  filter(Disease == "Control")
meta_wdiv_pd <- meta_wdiv %>%
  filter(Disease == "PD")

parkinsons_dataset_rare_no.NA_con <- parkinsons_dataset_rare_no.NA %>% subset_samples(Disease == "Control")
parkinsons_dataset_rare_no.NA_pd <- parkinsons_dataset_rare_no.NA %>% subset_samples(Disease == "PD")

#_____________________________________________________
# Bray-Curtis

# Plot PCoA plot with Bray-Curtis Metrics
beta_distance_bc <- distance(parkinsons_dataset_rare_no.NA, method="bray")
beta_pcoa_bc <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance=beta_distance_bc)

plot_beta_pcoa_bc_disease <- plot_ordination(parkinsons_dataset_rare_no.NA, beta_pcoa_bc, color="sodium_tertiles") +
  labs(pch="Disease", col = "sodium_tertiles") + 
  scale_color_gradient(low = "yellow", high = "purple") +
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  facet_wrap(.~Disease)  + 
  geom_point(size=1) +
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) +
  theme_gray(base_size=18)
plot_beta_pcoa_bc_disease

ggsave("plot_beta_pcoa_bc_disease.png"
       , plot_beta_pcoa_bc_disease
       , height=8, width=16)

# bray PERMANOVA

# Disease
beta_bray <- vegdist(t(otu_table(parkinsons_dataset_rare_no.NA)), method="bray")
bray <- adonis2(beta_bray ~ `Disease` + Age, data=meta_wdiv)
bray
write.csv(bray, file = "bray.csv", row.names = TRUE)

# Control Sodium
beta_bray_con <- vegdist(t(otu_table(parkinsons_dataset_rare_no.NA_con)), method="bray")
bray_con <- adonis2(beta_bray_con ~ `Sodium` + Age, data=meta_wdiv_con)
bray_con
write.csv(bray_con, file = "bray_con.csv", row.names = TRUE)

# PD Sodium
beta_bray_pd <- vegdist(t(otu_table(parkinsons_dataset_rare_no.NA_pd)), method="bray")
bray_pd <- adonis2(beta_bray_pd ~ `Sodium` + Age, data=meta_wdiv_pd)
bray_pd
write.csv(bray_pd, file = "bray_pd.csv", row.names = TRUE)

#_____________________________________________________
# Weighted Unifrac

# Disease
dm_unifrac_weight <- UniFrac(parkinsons_dataset_rare_no.NA, weighted=TRUE)
# Control Sodium
dm_unifrac_weight_con <- UniFrac(parkinsons_dataset_rare_no.NA_con, weighted=TRUE)
# PD Sodium
dm_unifrac_weight_pd <- UniFrac(parkinsons_dataset_rare_no.NA_pd, weighted=TRUE)

# Plot the above as an ordination to a PCoA plot, with Stats Elipses
beta_ord.wunifrac <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance="wunifrac")
plot_beta_ord.wunifrac_sodium_con.PD <-plot_ordination(parkinsons_dataset_rare_no.NA, beta_ord.wunifrac, color = "sodium_tertiles") +
  scale_color_gradient(low = "yellow", high = "purple") +
  facet_wrap(.~ Disease) +
  geom_point(size=1) +
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) + 
  theme_gray(base_size=18)
plot_beta_ord.wunifrac_sodium_con.PD

ggsave("plot_beta_ord.wunifrac_sodium_con.PD.png"
       , plot_beta_ord.wunifrac_sodium_con.PD
       , height=8, width=16)

# Weighted Unifrac PERMANOVA
# Disease
unif_weight <- adonis2(dm_unifrac_weight ~ `Disease` + Age, data=meta_wdiv)
unif_weight
write.csv(unif_weight, file = "unif_weight.csv", row.names = TRUE)
# Control Sodium
unif_weight_sodium_con <- adonis2(dm_unifrac_weight_con ~ `Sodium` + Age, data=meta_wdiv_con)
unif_weight_sodium_con
write.csv(unif_weight_sodium_con, file = "unif_weight_sodium_con.csv", row.names = TRUE)
# PD Sodium
unif_weight_sodium_pd <- adonis2(dm_unifrac_weight_pd ~ `Sodium` + Age, data=meta_wdiv_pd)
unif_weight_sodium_pd
write.csv(unif_weight_sodium_pd, file = "unif_weight_sodium_pd.csv", row.names = TRUE)

#_____________________________________________________
# Unweighted Unifrac

# Disease
dm_unifrac_unweight <- UniFrac(parkinsons_dataset_rare_no.NA, weighted=FALSE)
# Control Sodium
dm_unifrac_unweight_con <- UniFrac(parkinsons_dataset_rare_no.NA_con, weighted=FALSE)
# PD Sodium
dm_unifrac_unweight_pd <- UniFrac(parkinsons_dataset_rare_no.NA_pd, weighted=FALSE)

# Plot the above as an ordination to a PCoA plot, with Stats Elipses
beta_ord.unifrac <- ordinate(parkinsons_dataset_rare_no.NA, method="PCoA", distance="unifrac")
plot_beta_ord.unifrac_sodium_con.PD <-plot_ordination(parkinsons_dataset_rare_no.NA, beta_ord.unifrac, color = "sodium_tertiles") +
  scale_color_gradient(low = "yellow", high = "purple") +
  facet_wrap(.~ Disease) +
  geom_point(size=1) +
  stat_ellipse(type = "norm", aes(group = sodium_tertiles)) + 
  theme(text = element_text(size=15),
        axis.text.x = element_text(angle = 90)) +
  theme_gray(base_size=18)
plot_beta_ord.unifrac_sodium_con.PD

ggsave("plot_beta_ord.unifrac_sodium_con.PD.png"
       , plot_beta_ord.unifrac_sodium_con.PD
       , height=8, width=16)

# Unweighted Unifrac PERMANOVA
# Disease
unif_unweight <- adonis2(dm_unifrac_unweight ~ `Disease` + Age, data=meta_wdiv)
unif_unweight
write.csv(unif_unweight, file = "unif_unweight.csv", row.names = TRUE)
# Control Sodium
unif_unweight_sodium_con <- adonis2(dm_unifrac_unweight_con ~ `Sodium` + Age, data=meta_wdiv_con)
unif_unweight_sodium_con
write.csv(unif_unweight_sodium_con, file = "unif_unweight_sodium_con.csv", row.names = TRUE)
# PD Sodium
unif_unweight_sodium_pd <- adonis2(dm_unifrac_weight_pd ~ `Sodium` + Age, data=meta_wdiv_pd)
unif_unweight_sodium_pd
write.csv(unif_unweight_sodium_pd, file = "unif_unweight_sodium_pd.csv", row.names = TRUE)

#_____________________________________________________
