
#!/usr/bin/env Rscript
library(tidyverse)
library(phyloseq)
library(DESeq2)

####Load data/phyloseq object into RStudio####

load("parkinsons_dataset_final.RData")

###Filter out NA's in Sodium, Age and Disease columns###
parkinsons_dataset_rare_no.NA_2 <- parkinsons_dataset_final %>% 
  subset_samples(!is.na(Sodium))%>% 
  subset_samples(!is.na(Age))%>% 
  subset_samples(!is.na(Disease))%>% 
  subset_samples(Sodium < 5000)%>%
  tax_glom('Genus') 

###Scale variables of interest###
sample_data(parkinsons_dataset_rare_no.NA_2)$Age = scale(sample_data(parkinsons_dataset_rare_no.NA_2)$Age)
sample_data(parkinsons_dataset_rare_no.NA_2)$Sodium = scale(sample_data(parkinsons_dataset_rare_no.NA_2)$Sodium)

#### Run DESeq analysis####
## NOTE: Due to zeros error, add '1' count to all reads
pd_plus1_2 <- transform_sample_counts(parkinsons_dataset_rare_no.NA_2, function(x) x+1)
pd_deseq_2 <- phyloseq_to_deseq2(pd_plus1_2, ~`Sodium` + `Age` + `Disease`)
DESEQ_pd_2 <- DESeq(pd_deseq_2)
res2 <- results(DESEQ_pd_2, tidy=TRUE) 

View(res2)

###Plot results of DESeq analysis in a volcano plot###
ggplot(res2) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))

# Distinguish variables by whether they are significant or represent a large change by changing the color
vol_plot_tg <- res2 %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

# Save volcano plot to the working directory
ggsave(filename="vol_plot_tg.png",vol_plot_tg)

###Plot results of DESeq analysis in a table###
sigASVs_2 <- res2 %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>%
  dplyr::rename(ASV=row)
View(sigASVs_2)

# Get only ASV names
sigASVs_vec_2 <- sigASVs_2 %>%
  pull(ASV)

# Prune phyloseq file
pd_DESeq_2 <- prune_taxa(sigASVs_vec_2,parkinsons_dataset_rare_no.NA_2)
sigASVs_2 <- tax_table(pd_DESeq_2) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(sigASVs_2) %>%
  arrange(log2FoldChange) %>%
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

# Generate table 

#white background
DESeq2_table_tg <-ggplot(sigASVs_2) +
  geom_bar(aes(x=log2FoldChange, y=Genus, fill= log2FoldChange<0.0), stat="identity") +
  geom_errorbar(aes(y=Genus, xmin=log2FoldChange-lfcSE, xmax=log2FoldChange+lfcSE)) +
  theme_classic(base_size = 14) +
  theme(axis.text.x = element_text(hjust=1, vjust=0.5))

#gray square background
DESeq2_table_2_tg <-ggplot(sigASVs_2) +
  geom_bar(aes(x=log2FoldChange, y=Genus, fill= log2FoldChange<0.0), stat="identity") +
  geom_errorbar(aes(y=Genus, xmin=log2FoldChange-lfcSE, xmax=log2FoldChange+lfcSE)) +
  theme(axis.text.x = element_text(hjust=1, vjust=0.5))

# Save tables to the working directory
ggsave(filename="DESeq2_table_tg.png", DESeq2_table_tg)
ggsave(filename="DESeq2_table_2_tg.png", DESeq2_table_2_tg) 
