
#!/usr/bin/env Rscript

library(tidyverse)
library(phyloseq)
library(DESeq2)

####Load phyloseq object into RStudio####

load("parkinsons_dataset_final.RData")

###Filter out outliers and NA's in Sodium, Age and Disease columns, glom taxa to Genus level###
parkinsons_dataset_rare_no.NA <- parkinsons_dataset_final %>% 
  subset_samples(!is.na(Sodium))%>% 
  subset_samples(!is.na(Age))%>% 
  subset_samples(!is.na(Disease))%>% 
  subset_samples(Sodium < 5000)%>%
  tax_glom('Genus')

##Filter to contain only PD patients##
parkinsons_dataset_pd_filter <- subset_samples(parkinsons_dataset_rare_no.NA, Disease == "PD")

##Check that data was correctly split to only contain PD patients by checking number of samples##
nsamples(parkinsons_dataset_pd_filter)

###Scale variables of interest###
sample_data(parkinsons_dataset_pd_filter)$Age = scale(sample_data(parkinsons_dataset_pd_filter)$Age)
sample_data(parkinsons_dataset_pd_filter)$Sodium = scale(sample_data(parkinsons_dataset_pd_filter)$Sodium)

###Check data distribution by generating a histogram###
hist(sample_data(parkinsons_dataset_pd_filter)$Sodium)

#### Run DESeq analysis####
## NOTE: Due to zeros error, add '1' count to all reads
## NOTE2: Make sure to control for Age 
pd_plus1 <- transform_sample_counts(parkinsons_dataset_pd_filter, function(x) x+1)
pd_deseq <- phyloseq_to_deseq2(pd_plus1, ~`Sodium` + `Age`)
DESEQ_pd <- DESeq(pd_deseq)
res <- results(DESEQ_pd, tidy=TRUE) 

View(res)

###Plot results of DESeq analysis in a volcano plot###
ggplot(res) +
  geom_point(aes(x=log2FoldChange, y=-log10(padj)))

# Distinguish variables by whether they are significant or represent a large change by changing the color
vol_plot <- res %>%
  mutate(significant = padj<0.01 & abs(log2FoldChange)>2) %>%
  ggplot() +
  geom_point(aes(x=log2FoldChange, y=-log10(padj), col=significant))

# Save volcano plot to the working directory
ggsave(filename="aim3_vol_plot.png",vol_plot)

###Plot results of DESeq analysis in a table###
# Total cohort
res_totalcohort = read.csv('deseq_results_totalcohort.csv') %>%
  dplyr::rename(ASV=row) %>% 
  filter(padj<0.01 & abs(log2FoldChange)>2) %>% 
  arrange(log2FoldChange) %>% 
  mutate(ASV = factor(ASV, levels = .$ASV))
# Current cohort
res = res %>%
  dplyr::rename(ASV=row) %>% 
  filter(ASV %in% res_totalcohort$ASV) %>% 
  mutate(Sig = padj<0.01 & abs(log2FoldChange)>2)

# Prune phyloseq file
pd_DESeq <- prune_taxa(res$ASV,parkinsons_dataset_rare_no.NA)
sigASVs <- tax_table(pd_DESeq) %>% as.data.frame() %>%
  rownames_to_column(var="ASV") %>%
  right_join(res) %>%
  mutate(ASV = factor(ASV, levels = res_totalcohort$ASV)) %>% 
  arrange(ASV) %>% 
  mutate(Genus = make.unique(Genus)) %>%
  mutate(Genus = factor(Genus, levels=unique(Genus)))

# Generate table 

#white background
Aim3_DESeq_table <-ggplot(sigASVs) +
  geom_bar(aes(x=log2FoldChange, y=Genus, fill= log2FoldChange<0.0, alpha = Sig), stat="identity") +
  geom_errorbar(aes(x=log2FoldChange, y=Genus, xmin=log2FoldChange-lfcSE, xmax=log2FoldChange+lfcSE)) +
  scale_alpha_manual(values = c(0.4,1)) + # the darker ones should be significant
  theme_classic(base_size = 14) +
  theme(axis.text.x = element_text(hjust=1, vjust=0.5))

#gray square background
Aim3_DESeq2_table_2 <-ggplot(sigASVs) +
  geom_bar(aes(x=log2FoldChange, y=Genus, fill= log2FoldChange<0.0, alpha = Sig), stat="identity") +
  geom_errorbar(aes(x=log2FoldChange, y=Genus, xmin=log2FoldChange-lfcSE, xmax=log2FoldChange+lfcSE)) +
  scale_alpha_manual(values = c(0.4,1))  # the darker ones should be significant

# Save tables to the working directory
ggsave(filename="Aim3_DESeq_table_FINAL.png", Aim3_DESeq_table)
ggsave(filename="Aim3_DESeq_table_FINAL_PD.png", Aim3_DESeq2_table_2 ) 
